package xmldb;

/**
 * <p>This is a trivial implementation of the {@link Index} interface.
 * It indexes all the XML Tokens in a simple array.</p>
 *
 * <p>XML Technologies WS 15/16 - Assignments<br/>
 * Workgroup DBIS, University of Konstanz</p>
 */
public class ArrayIndex implements Index {
  /** This array serves as a container for all indexed tokens. */
  String[] tokens = new String[16];
  /** Number of indexed tokens. */
  int size = 0;
  /** Iterator array position. */
  int itPos; 

  /**
   * Checks if the specified token is already indexed; if yes, returns its
   * reference. Otherwise, creates a new index entry and returns a
   * reference of the indexed token.
   * @param token token to be indexed
   * @return indexed token reference
   */
  public String index(String token) {
    // check if token was already indexed; if yes, return reference
    String t = get(token);
    if(t != null) return t;
    
    // if array is full, array size is doubled
    if(size == tokens.length) {
      String[] tmp = new String[size << 1];
      System.arraycopy(tokens, 0, tmp, 0, size);
      tokens = tmp;
    }
    
    // add token
    tokens[size++] = token;
    return token;
  }

  /**
   * Finds the specified token in the index and returns its reference.
   * @param token token to be found
   * @return token or null if token was not found
   */
  public String get(String token) {
    for(int i = 0; i < size; i++) {
      if(token.equals(tokens[i])) return tokens[i];
    }
    return null;
  }

  /**
   * Returns the number of index entries.
   * @return number of index entries
   */
  public int size() {
    return size;
  }

  /**
   * Initializes the index iterator.
   */
  public void init() {
    itPos = -1;
  }

  /**
   * Checks if the iterator has more tokens.
   * @return true if more tokens exist
   */
  public boolean more() {
    return ++itPos < size;
  }

  /**
   * Return the next iterator token.
   * @return next iterator token
   */
  public String next() {
    return tokens[itPos];
  }
}
