package xmldb;

/**
 * <p>This class contains variables and methods which
 * are used by several classes.</p>
 *
 * <p>XML Technologies WS 15/16 - Assignments<br/>
 * Workgroup DBIS, University of Konstanz</p>
 */
abstract class Constants {
  /**
   * Name of your index implementation.
   * TODO: Change the reference to your own index implementation
   */
  static final Class<? extends Index> INDEX = ArrayIndex.class;

  /** Default file to be parsed. */
  static final String INPUT = "input.xml";
//  static final String INPUT = "factbook.xml";

  /** Token types. */
  enum Token {
    INVALID, L_BR, NAME, R_BR, SPACE, ATT_VAL,
    L_BR_CLOSE, CLOSE_R_BR, TEXT, EQ, QUOTE;
  };

  /** Node kinds. */
  enum Kind { DOC, ELEM, TEXT };
 
  /** Timer. */
  private long time;

  /** Initializes the timer. */
  void initTimer() {
    time = System.nanoTime();
  }

  /**
   * Prints the spent time in milliseconds and initialized the timer.
   */
  void printTimer() {
    long t = (System.nanoTime() - time) / 1000000;
    System.out.println("Time needed: " + t + " ms");
    initTimer();
  }

  /**
   * Prints the memory consumption in kilobytes.
   */
  void printMem() {
    Runtime rt = Runtime.getRuntime();
    long m = (rt.totalMemory() - rt.freeMemory()) >> 10;
    System.out.println("Memory used: " + m + " kb");
  }
  
  /**
   * Dump verbose information.
   * @param info the string to be dumped
   */
  void verbose(String info) {
    // extract letter from class name and dump message
    char ch = getClass().getSimpleName().charAt(0);
    System.out.println("[" + ch + "] " + info);
  }

  /**
   * Dumps an error message.
   * @param info the error to be dumped
   */
  void error(String info) {
    // extract letter from class name and dump message
    char ch = getClass().getSimpleName().charAt(0);
    System.out.println("[" + ch + "] " + info);
  }
}
